@@ -18,12 +18,20 @@ You should have received a copy of the GNU General Public License
 along with GNU GPERF; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.  */
 
+/* AIX requires the alloca decl to be the first thing in the file. */
+#ifdef __GNUC__
+#define alloca __builtin_alloca
+#elif defined(sparc)
+#include <alloca.h>
+#elif defined(_AIX)
+#pragma alloca
+#else
+char *alloca ();
+#endif
+
 #include <stdio.h>
 #include <builtin.h>
 #include <assert.h>
-#ifdef sparc
-#include <alloca.h>
-#endif
 #include "options.h"
 #include "read-line.h"
 #include "hash-table.h"
