@@ -287,14 +287,14 @@ int obscure_syntax = 0;
    necessary.  */
 #define PATFETCH(c)							\
   {if (p == pend) goto end_of_pattern;					\
-  c = * (unsigned char *) p++;						\
+  c = * (const unsigned char *) p++;						\
   if (translate) c = translate[c]; }
 
 /* Fetch the next character in the uncompiled pattern, with no
    translation.  */
 #define PATFETCH_RAW(c)							\
  {if (p == pend) goto end_of_pattern;					\
-  c = * (unsigned char *) p++; }
+  c = * (const unsigned char *) p++; }
 
 #define PATUNFETCH p--
 
@@ -385,10 +385,10 @@ char *
 re_compile_pattern (const char *pattern, int size, struct re_pattern_buffer *bufp)
 {
   register char *b = bufp->buffer;
-  register char *p = pattern;
-  char *pend = pattern + size;
+  register const char *p = pattern;
+  const char *pend = pattern + size;
   register unsigned c, c1;
-  char *p1;
+  const char *p1;
   unsigned char *translate = (unsigned char *) bufp->translate;
 
   /* Address of the count-byte of the most recently inserted `exactn'
@@ -429,7 +429,7 @@ re_compile_pattern (const char *pattern, int size, struct re_pattern_buffer *buf
 
   /* Place in pattern (i.e., the {) to which to go back if the interval
      is invalid.  */
-  char *beg_interval = 0;
+  const char *beg_interval = 0;
   
   /* Stack of information saved by \( and restored by \).
      Four stack elements are pushed by each \(:
@@ -479,7 +479,7 @@ re_compile_pattern (const char *pattern, int size, struct re_pattern_buffer *buf
 	{
 	case '$':
 	  {
-	    char *p1 = p;
+	    const char *p1 = p;
 	    /* When testing what follows the $,
 	       look past the \-constructs that don't consume anything.  */
 	    if (! (obscure_syntax & RE_CONTEXT_INDEP_OPS))
